@@ -1,10 +1,9 @@
 # Archivo con tus funciones
-
 import datetime
 import numpy as np
 
 
-# CREAR ARRAY DE FECHAS
+# CREAR ARRAY DE FECHAS EN FORMATO DATETIME
 def createTspan(fecha_inicio,fecha_final,deltaT_min):
     """ Esta funcion crea un array de timestamps que incian en f0 y terminan en fE con un avance de tiempo del detalT minutos.
     f0 y fE son fechas en formato datetime. I.e., datetime(2025, 1, 1, 0, 0, 0) 
@@ -12,8 +11,8 @@ def createTspan(fecha_inicio,fecha_final,deltaT_min):
     **********
     Example of use:
     The measurement is made every ten mins, starting time [2025,1,1,0,0,0] ending time [2025,1,1,1,0,0]
-    f0 = datetime(2025,1,1,0,0,0)
-    fe = datetime(2025,1,1,1,0,0)
+    fecha_inicio = datetime(2025,1,1,0,0,0)
+    fecha_final = datetime(2025,1,1,1,0,0)
     deltaT = 10 (10 minutes each measurement)
     # Resultado esperado
     tspan = [datetime.datetime(2025, 1, 1, 0, 0), datetime.datetime(2025, 1, 1, 0, 10), datetime.datetime(2025, 1, 1, 0, 20), datetime.datetime(2025, 1, 1, 0, 30), datetime.datetime(2025, 1, 1, 0, 40), datetime.datetime(2025, 1, 1, 0, 50), datetime.datetime(2025, 1, 1, 1, 0)]
@@ -30,8 +29,7 @@ def createTspan(fecha_inicio,fecha_final,deltaT_min):
         actual += datetime.timedelta(minutes=deltaT_min)
     return vector_fechas
 
-
-# FECHAS DE MATLAB A PYTHON
+# FECHAS DE MATLAB A PYTHON en formato datetime
 def datenum_to_datetime(datenum):
     """Lee un array en formato datenum de matlab (numeros de orden 7XXXXX) y los cambia al formato datetime de python.
     Por lo general los datos datenum vienen desde un archivo netCDF generado por matlab por lo que pueden venir como un Masked Array.
@@ -63,12 +61,13 @@ def datenum_to_datetime(datenum):
         fecha = fecha.replace(microsecond=0)
         if fecha.second >= 30:
             fecha += datetime.timedelta(minutes=1)
-        
+            fecha.replace(second=0)
         fechas_convertidas.append(fecha)
 
     # Retorna las fechas convertidas como un array de numpy
     return np.array(fechas_convertidas)
 
+# FECHAS DE MATLAB A PYTHON EN FORMATO STRING
 def datenum_to_datetimeStr(datenum,format="%Y/%m/%d %H:%M"):
     """Lee un array en formato datenum de matlab (numeros de orden 7XXXXX) y los cambia al formato string elegido por el usuario.
     Por defecto el formato es 'YYYY/mm/dd HH:MM'
@@ -84,6 +83,7 @@ def datenum_to_datetimeStr(datenum,format="%Y/%m/%d %H:%M"):
     tspan_str = [t.strftime(format) for idx, t in enumerate(tspan)]
     return tspan_str
 
+# FECHAS DE PYTHON A FORMATO STRING
 def datetimeStr(tspan,format="%Y/%m/%d %H:%M"):
     """Recibe un array datetime de python y lo cambia al formato string elegido por el usuario. 
     Por defecto el formato es 'YYYY/mm/dd HH:MM'
